orca r3797 - trunk/src/orca/scripts



Author: richb
Date: Wed Apr  2 21:28:16 2008
New Revision: 3797
URL: http://svn.gnome.org/viewvc/orca?rev=3797&view=rev

Log:
Extra change to catch the "has stopped typing" messages.


Modified:
   trunk/src/orca/scripts/gaim.py

Modified: trunk/src/orca/scripts/gaim.py
==============================================================================
--- trunk/src/orca/scripts/gaim.py	(original)
+++ trunk/src/orca/scripts/gaim.py	Wed Apr  2 21:28:16 2008
@@ -801,10 +801,12 @@
                 message = message[1:]
 
             # If the user doesn't want announcements for when their buddies
             # are typing, and this is such a message, then just return.
             #
             if not announceBuddyTyping and \
-               message.endswith(_(" is typing...")):
+               (message.endswith(_(" is typing...")) or \
+                message.endswith(_(" has stopped typing")):
                 return
 
             chatRoomName = self.getDisplayedText(chatRoomTab)
@@ -801,10 +801,12 @@
 
             # If the user doesn't want announcements for when their buddies
-            # are typing, and this is such a message, then just return.
+            # are typing (or have stopped typing), and this is such a message,
+            # then just return.
             #
             if not announceBuddyTyping and \



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]